@@ -37,7 +37,7 @@ from datetime import datetime, timedelta
 
 import cron
 
-__version__='0.1.5'
+__version__='0.1.6'
 last_version_url='http://www.magikmon.com/download/mkbackup_last.txt'
 
 windows_codepage='cp1252'
@@ -270,7 +270,7 @@ class NtBackup:
                 log.error('%s=%r %s', k, job.get(k,''), v)
                 msg_body+='%s=%r\n    %s\n\n' % (k, job.get(k,''), v)
             if mail_config and not command=='check':
-                subject='MKBACKUP: CONFIG ERR %s ' % (command, job['name'])
+                subject='MKBACKUP: CONFIG ERR %s ' % (job['name'], )
                 sendmail(job['sender'], job['recipients'], subject, msg_body, [], job['smtp_host'], job['smtp_port'])
 
             # --------->  RETURN <-----------
@@ -460,9 +460,12 @@ def FormatEv(ev_obj, logtype):
     return msg 
 
 def ReadEvLog(logtype, source, start, end=None):
+    # If any event is not 'INFO' => return 'ERR'
+    # If the last event is not an 'INFO' => return 'WAR' (in fact when not event are present)
+    # Else return 'OK'
     flags = win32evtlog.EVENTLOG_BACKWARDS_READ|win32evtlog.EVENTLOG_SEQUENTIAL_READ
     hand=win32evtlog.OpenEventLog(None, logtype) # None for localhost
-    cont, output, status='first', u'', 'ERR'
+    cont, output, status='first', u'', 'WAR'
     while cont:
         events=win32evtlog.ReadEventLog(hand,flags,0)
         for ev_obj in events:
@@ -472,6 +475,9 @@ def ReadEvLog(logtype, source, start, end=None):
             if int(ev_obj.TimeGenerated)<start:
                 cont=False
                 break
+            if ev_obj.EventType!=win32con.EVENTLOG_INFORMATION_TYPE:
+                status='ERR'
+
             if cont=='first':
                 #print 'first %r %r %r %r' % (ev_obj.EventID=='8001', ev_obj.EventType==win32con.EVENTLOG_INFORMATION_TYPE, ev_obj.EventID, ev_obj.EventType)
                 cont=True
@@ -481,7 +487,7 @@ def ReadEvLog(logtype, source, start, end=None):
             if output:
                 output=FormatEv(ev_obj, logtype)+u'\r\n'+output
             else:
-            		output=FormatEv(ev_obj, logtype)
+            	output=FormatEv(ev_obj, logtype)
 
         cont=cont and events
     win32evtlog.CloseEventLog(hand)
@@ -608,7 +614,7 @@ log.setLevel(logging.INFO)
 log.addHandler(root_handler)
 
 if cmd_options.debug:
-    root_logger.setLevel(logging.DEBUG)
+    log.setLevel(logging.DEBUG)
 else:
     # this stop early the logging process of loglevel<=DEBUG and should 
     # improve performance a little bit
@@ -763,5 +769,3 @@ for job_name in job_list:
 # Win2k8: the backups are stored inside the <drive_letter>:\WindowsImageBackup\<machineName>\SystemStateBackup
 # Win2k8 R2: the backups are stored inside the <drive_letter>:\WindowsImageBackup\<machineName>\BackupSet<..>\ path
 
-
- 
